# Pyrocko streaming Submodule

pyrocko ships with basic streaming (realtime) IO modules.

* `pyrocko.streaming.edl` EDL support.
* `pyrocko.streaming.slink` Seedlink support through `rdseed`
* `pyrocko.streaming.serial_hamster` Stream data flooding through your serial port

See also `snuffler` streaming capabilities as well as the `hamster` app.
